/*
   FALCON - The Falcon Programming Language.
   FILE: verion.h

   Regex module version informations
   -------------------------------------------------------------------
   Author: Giancarlo Niccolai
   Begin: 2007-07-25


   -------------------------------------------------------------------
   (C) Copyright 2004: the FALCON developers (see list in AUTHORS file)

   See LICENSE file for licensing details.
*/

#ifndef VERSION_H
#define VERSION_H

#define VERSION_MAJOR        1
#define VERSION_MINOR        0
#define VERSION_REVISION     1

#endif

/* end of version.h */
